Changelog
#########

0.2.0
=====

* Add support for Django 4.0
* Drop support for Django 2.2, 3.0, and 3.1

0.1.4
=====

* Ensure that URLs using `i18n_patterns` are properly exported

0.1.3
=====

* Fix Django version in README

0.1.2
=====

* Fix package classifiers

0.1.1
=====

* Add official support for Python 3.8

0.1.0
=====

This is the initial release of Django-js-routes.
